<a id="autonomy.fsm.scaffold.templates.components"></a>

# autonomy.fsm.scaffold.templates.components

Templates for FSM components

<a id="autonomy.fsm.scaffold.templates.components.ROUNDS"></a>

## ROUNDS Objects

```python
@dataclass
class ROUNDS()
```

Template for rounds.py

<a id="autonomy.fsm.scaffold.templates.components.BEHAVIOURS"></a>

## BEHAVIOURS Objects

```python
@dataclass
class BEHAVIOURS()
```

Template for behaviours.py

<a id="autonomy.fsm.scaffold.templates.components.PAYLOADS"></a>

## PAYLOADS Objects

```python
@dataclass
class PAYLOADS()
```

Template for payloads.py

<a id="autonomy.fsm.scaffold.templates.components.MODELS"></a>

## MODELS Objects

```python
@dataclass
class MODELS()
```

Template for models.py

<a id="autonomy.fsm.scaffold.templates.components.HANDLERS"></a>

## HANDLERS Objects

```python
@dataclass
class HANDLERS()
```

Template for handlers.py

<a id="autonomy.fsm.scaffold.templates.components.DIALOGUES"></a>

## DIALOGUES Objects

```python
@dataclass
class DIALOGUES()
```

Template for dialogues.py

